pub struct LocalNetConfig {Show 16 fields
pub database: Database,
pub network: NetworkConfig,
pub testing_prng_seed: Option<u64>,
pub namespace: String,
pub num_other_initial_chains: u32,
pub initial_amount: Amount,
pub num_initial_validators: usize,
pub num_shards: usize,
pub num_proxies: usize,
pub policy_config: ResourceControlPolicyConfig,
pub http_request_allow_list: Option<Vec<String>>,
pub cross_chain_config: CrossChainConfig,
pub storage_config_builder: InnerStorageConfigBuilder,
pub path_provider: PathProvider,
pub block_exporters: ExportersSetup,
pub binary_dir: Option<PathBuf>,
}Expand description
The information needed to start a LocalNet.
Fields
database: DatabaseThe storage backend used by the validators.
network: NetworkConfigThe network protocols used for the validators’ internal and external endpoints.
testing_prng_seed: Option<u64>The seed used to make key generation deterministic in tests, if any.
namespace: StringThe namespace used for the validators’ storage.
num_other_initial_chains: u32The number of additional chains to create in the genesis configuration.
initial_amount: AmountThe initial balance assigned to each chain in the genesis configuration.
num_initial_validators: usizeThe number of validators to start initially.
num_shards: usizeThe number of shards to run per validator.
num_proxies: usizeThe number of proxies to run per validator.
policy_config: ResourceControlPolicyConfigThe resource control policy applied to the network.
http_request_allow_list: Option<Vec<String>>The list of hosts that applications are allowed to make HTTP requests to, if restricted.
cross_chain_config: CrossChainConfigThe configuration for cross-chain message queuing between validators.
storage_config_builder: InnerStorageConfigBuilderThe builder that produces the storage configuration for the network.
path_provider: PathProviderThe provider for the working directory of the network.
block_exporters: ExportersSetupThe setup describing how block exporters are started or connected to.
binary_dir: Option<PathBuf>Optional directory where the linera, linera-proxy, and linera-server binaries
are located. If None, binaries are resolved from the current binary’s directory.
Implementations