pub struct LocalNet { /* private fields */ }Expand description
A set of Linera validators running locally as native processes.
Implementations
Sourceimpl LocalNet
impl LocalNet
Sourcepub fn genesis_config(&self) -> Result<GenesisConfig>
pub fn genesis_config(&self) -> Result<GenesisConfig>
Reads the genesis configuration of the local network.
Sourcepub fn proxy_public_port(&self, validator: usize, proxy_id: usize) -> usize
pub fn proxy_public_port(&self, validator: usize, proxy_id: usize) -> usize
Returns the public port of the given proxy of the given validator.
Sourcepub fn first_public_port() -> usize
pub fn first_public_port() -> usize
Returns the public port of the first proxy of the first validator.
Sourcepub async fn ensure_grpc_server_has_started(
nickname: &str,
port: usize,
scheme: &str,
) -> Result<()>
pub async fn ensure_grpc_server_has_started( nickname: &str, port: usize, scheme: &str, ) -> Result<()>
Waits until the gRPC server at the given port responds as healthy.
Sourcepub async fn start_validator(&mut self, index: usize) -> Result<()>
pub async fn start_validator(&mut self, index: usize) -> Result<()>
Start a validator.
Sourcepub async fn restart_validator(&mut self, index: usize) -> Result<()>
pub async fn restart_validator(&mut self, index: usize) -> Result<()>
Restart a validator. This is similar to start_validator except that the
database was already initialized once.
Sourcepub async fn stop_validator(&mut self, index: usize) -> Result<()>
pub async fn stop_validator(&mut self, index: usize) -> Result<()>
Terminates all the processes of a given validator.
Sourcepub fn validator_client(&mut self, validator: usize) -> Result<Client>
pub fn validator_client(&mut self, validator: usize) -> Result<Client>
Returns a linera_rpc::Client to interact directly with a validator.
Sourcepub fn validator_address(&self, validator: usize) -> String
pub fn validator_address(&self, validator: usize) -> String
Returns the address to connect to a validator’s proxy. In local networks, the zeroth proxy is the validator ingress.
Sourceimpl LocalNet
impl LocalNet
Sourcepub fn validator_keys(&self, validator: usize) -> Option<&(String, String)>
pub fn validator_keys(&self, validator: usize) -> Option<&(String, String)>
Returns the validating key and an account key of the validator.
Sourcepub async fn generate_validator_config(
&mut self,
validator: usize,
) -> Result<()>
pub async fn generate_validator_config( &mut self, validator: usize, ) -> Result<()>
Generates the configuration and keys for the given validator.
Sourcepub async fn terminate_server(
&mut self,
validator: usize,
shard: usize,
) -> Result<()>
pub async fn terminate_server( &mut self, validator: usize, shard: usize, ) -> Result<()>
Terminates the server for the given shard of the given validator.
Sourcepub fn remove_validator(&mut self, validator: usize) -> Result<()>
pub fn remove_validator(&mut self, validator: usize) -> Result<()>
Removes the given validator from the set of running validators.